@@ -11,13 +11,13 @@
 #    under the License.
 
 import contextlib
+from io import BytesIO
 import json
 import logging
 import os
-import six
-import six.moves.urllib.parse as urlparse
 import testtools
 import time
+import urllib.parse as urlparse
 import uuid
 
 from glanceclient import client as gclient
@@ -35,7 +35,7 @@ import selenium.webdriver.common.by as by
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support import ui
 
-import config.config as cfg
+from muranodashboard.tests.functional.config import config as cfg
 from muranodashboard.tests.functional import consts
 from muranodashboard.tests.functional import utils
 
@@ -140,7 +140,7 @@ class UITestCase(testtools.TestCase):
                                              project=tenant_id,
                                              enabled=True)
         roles = cls.keystone_client.roles.list()
-        role_id = [role.id for role in roles if role.name == 'Member'][0]
+        role_id = [role.id for role in roles if role.name == 'member'][0]
         users = cls.keystone_client.users.list()
         user_id = [user.id for user in users if user.name == name][0]
         cls.keystone_client.roles.grant(role_id, user=user_id,
@@ -160,7 +160,7 @@ class UITestCase(testtools.TestCase):
     def add_user_to_project(self, project_id, user_id, user_role=None):
         if not user_role:
             roles = self.keystone_client.roles.list()
-            role_id = [role.id for role in roles if role.name == 'Member'][0]
+            role_id = [role.id for role in roles if role.name == 'member'][0]
         if not user_id:
             user_name = cfg.common.user
             users = self.keystone_client.users.list()
@@ -418,7 +418,7 @@ class ImageTestCase(PackageBase):
                                              container_format='bare',
                                              is_public='True',
                                              murano_image_info=murano_property)
-            image_data = six.BytesIO(None)
+            image_data = BytesIO(None)
             cls.glance.images.upload(image['id'], image_data)
         except Exception:
             logger.error("Unable to create or update image in Glance")
