@@ -16,8 +16,8 @@ from django.core import exceptions
 from django.core import validators as django_validator
 from django import forms
 from django.utils.translation import ugettext_lazy as _
+from unittest import mock
 
-import mock
 import unittest
 
 from muranodashboard.dynamic_ui import fields
@@ -450,7 +450,7 @@ class TestPasswordField(unittest.TestCase):
                           'name', test_form_data)
 
     def test_deepcopy(self):
-        self.password_field.error_messages = None
+        self.password_field.error_messages = {}
         test_memo = {}
         result = self.password_field.__deepcopy__(test_memo)
         self.assertIsInstance(result, fields.PasswordField)
@@ -624,7 +624,10 @@ class TestImageChoiceField(unittest.TestCase):
                       status='active'),
             # Test whether second continue statement works.
             mock.Mock(id='bar_image_id', murano_property={
-                      'title': 'foo_image_title', 'type': 'jpg'},
+                      'title': 'bar_image_title', 'type': 'png'},
+                      status='active'),
+            mock.Mock(id='baz_image_id', murano_property={
+                      'title': 'baz_image_title', 'type': 'jpg'},
                       status='active')
         ]
         image_choice_field = fields.ImageChoiceField()
@@ -634,9 +637,17 @@ class TestImageChoiceField(unittest.TestCase):
 
         self.assertEqual(("", _("Select Image")),
                          image_choice_field.choices[0])
-        self.assertEqual("foo_image_id", image_choice_field.choices[1][0])
+        self.assertEqual("bar_image_id", image_choice_field.choices[1][0])
         self.assertIsInstance(image_choice_field.choices[1][1], fields.Choice)
 
+        # Test that 'Select Image' is dropped if only one result
+        image_choice_field.image_type = 'jpg'
+        image_choice_field.choices = []
+        image_choice_field.update(self.request)
+
+        self.assertEqual('baz_image_id', image_choice_field.choices[0][0])
+        self.assertIsInstance(image_choice_field.choices[0][1], fields.Choice)
+
         # Test whether first continue statement works.
         mock_get_murano_images.return_value = [
             mock.Mock(murano_property={
@@ -828,8 +839,9 @@ class TestAZoneChoiceField(unittest.TestCase):
     @mock.patch.object(fields, 'nova')
     def test_update(self, mock_nova):
         mock_nova.novaclient().availability_zones.list.return_value = [
-            mock.Mock(zoneName='foo_zone', zoneState='foo_state'),
-            mock.Mock(zoneName='bar_zone', zoneState='bar_state')
+            mock.Mock(zoneName='foo_zone', zoneState={'available': True}),
+            mock.Mock(zoneName='bar_zone', zoneState={'available': True}),
+            mock.Mock(zoneName='baz_zone', zoneState={'available': False})
         ]
         request = {'request': mock.Mock()}
         a_zone_choice_field = fields.AZoneChoiceField()
