@@ -28,7 +28,7 @@ PARAM_MAPPING = {
 
 @mock.patch.object(environments, 'api')
 @mock.patch.object(environments, 'env_api')
-class TestComponentsMetadataAPI(helpers.APITestCase):
+class TestComponentsMetadataAPI(helpers.RestAPITestCase):
 
     def setUp(self):
         super(TestComponentsMetadataAPI, self).setUp()
@@ -86,7 +86,7 @@ class TestComponentsMetadataAPI(helpers.APITestCase):
 
 @mock.patch.object(environments, 'api')
 @mock.patch.object(environments, 'env_api')
-class TestEnvironmentsMetadataApi(helpers.APITestCase):
+class TestEnvironmentsMetadataApi(helpers.RestAPITestCase):
 
     def setUp(self):
         super(TestEnvironmentsMetadataApi, self).setUp()
