@@ -14,8 +14,8 @@
 
 import ast
 from django import http as django_http
-import mock
-import testtools
+import unittest
+from unittest import mock
 
 from horizon import tables as hz_tables
 
@@ -25,7 +25,7 @@ from muranodashboard.environments import tables
 from muranodashboard.packages import consts as pkg_consts
 
 
-class TestEnvironmentTables(testtools.TestCase):
+class TestEnvironmentTables(unittest.TestCase):
     def test_check_row_actions_allowed(self):
         actions = mock.Mock()
         actions.table.data = None
@@ -359,7 +359,7 @@ class TestEnvironmentTables(testtools.TestCase):
         self.assertEqual('foo_name', tables.get_service_type(test_datum))
 
 
-class TestUpdateEnvironmentRow(testtools.TestCase):
+class TestUpdateEnvironmentRow(unittest.TestCase):
     def setUp(self):
         super(TestUpdateEnvironmentRow, self).setUp()
 
@@ -403,8 +403,10 @@ class TestUpdateEnvironmentRow(testtools.TestCase):
 
         data_table = tables.UpdateEnvironmentRow(self.mock_data_table)
 
-        with self.assertRaisesRegex(django_http.Http404, None):
+        with self.assertRaises(django_http.Http404) as cm:
             data_table.get_data(None, 'foo_environment_id')
+        e = cm.exception
+        self.assertEqual('', str(e))
 
     @mock.patch.object(tables, 'api')
     def test_get_data_except_exception(self, mock_api):
@@ -412,11 +414,13 @@ class TestUpdateEnvironmentRow(testtools.TestCase):
 
         data_table = tables.UpdateEnvironmentRow(self.mock_data_table)
 
-        with self.assertRaisesRegex(Exception, 'foo_error'):
+        with self.assertRaises(Exception) as cm:
             data_table.get_data(None, 'foo_environment_id')
+        e = cm.exception
+        self.assertEqual('foo_error', str(e))
 
 
-class TestUpdateServiceRow(testtools.TestCase):
+class TestUpdateServiceRow(unittest.TestCase):
 
     def setUp(self):
         super(TestUpdateServiceRow, self).setUp()
@@ -437,7 +441,7 @@ class TestUpdateServiceRow(testtools.TestCase):
             None, 'foo_env_id', 'foo_service_id')
 
 
-class TestUpdateEnvMetadata(testtools.TestCase):
+class TestUpdateEnvMetadata(unittest.TestCase):
 
     def test_update_env_meta_data(self):
         kwargs = {'datum': 'foo_datum'}
@@ -508,14 +512,15 @@ class TestUpdateEnvMetadata(testtools.TestCase):
             None, 'foo_env_id')
 
 
-class TestEnvironmentsTable(testtools.TestCase):
+class TestEnvironmentsTable(unittest.TestCase):
 
     @mock.patch.object(tables, 'reverse')
     @mock.patch.object(tables, 'policy')
     def test_environments_table(self, mock_policy, mock_reverse):
         mock_reverse.return_value = 'test_url'
         mock_env = mock.Mock(id='foo_env_id')
-        envs_table = tables.EnvironmentsTable(None)
+        mock_request = mock.Mock()
+        envs_table = tables.EnvironmentsTable(mock_request)
         self.assertEqual(tables.EnvironmentsTable.get_env_detail_link.__name__,
                          envs_table.columns['name'].get_link_url.__name__)
 
@@ -531,7 +536,7 @@ class TestEnvironmentsTable(testtools.TestCase):
             "horizon:app-catalog:environments:services", args=('foo_env_id',))
 
 
-class TestUpdateMetadata(testtools.TestCase):
+class TestUpdateMetadata(unittest.TestCase):
 
     def setUp(self):
         super(TestUpdateMetadata, self).setUp()
@@ -610,11 +615,12 @@ class TestUpdateMetadata(testtools.TestCase):
             None, 'foo_env_id')
 
 
-class TestServicesTable(testtools.TestCase):
+class TestServicesTable(unittest.TestCase):
 
     def test_get_object_id(self):
         test_datum = {'?': {'id': 'foo'}}
-        services_table = tables.ServicesTable(None)
+        mock_request = mock.Mock()
+        services_table = tables.ServicesTable(mock_request)
         self.assertEqual('foo', services_table.get_object_id(test_datum))
 
     @mock.patch.object(tables, 'pkg_api')
@@ -626,7 +632,8 @@ class TestServicesTable(testtools.TestCase):
         mock_pkg_api.package_list.return_value = (
             [foo_app, baz_app], True
         )
-        services_table = tables.ServicesTable(None)
+        mock_request = mock.Mock()
+        services_table = tables.ServicesTable(mock_request)
         services_table.request = None
         services_table._more = False
         expected = [{'foo': 'bar'}, {'baz': 'qux'}]
@@ -639,7 +646,8 @@ class TestServicesTable(testtools.TestCase):
 
     @mock.patch.object(tables, 'api')
     def test_actions_allowed(self, mock_api):
-        services_table = tables.ServicesTable(None)
+        mock_request = mock.Mock()
+        services_table = tables.ServicesTable(mock_request)
         mock_api.environment_get.return_value = mock.Mock(
             status=consts.STATUS_ID_READY)
         services_table.kwargs = {'environment_id': 'foo_env_id'}
@@ -648,12 +656,13 @@ class TestServicesTable(testtools.TestCase):
         mock_api.environment_get.return_value = mock.Mock(
             status=consts.STATUS_ID_DEPLOYING)
         self.assertFalse(services_table.actions_allowed())
-        mock_api.environment_get.assert_called_with(None, 'foo_env_id')
+        mock_api.environment_get.assert_called_with(mock_request, 'foo_env_id')
 
     @mock.patch.object(tables, 'catalog_views')
     def test_categories_list(self, mock_catalog_views):
         mock_catalog_views.get_categories_list.return_value = []
-        services_table = tables.ServicesTable(None)
+        mock_request = mock.Mock()
+        services_table = tables.ServicesTable(mock_request)
         services_table.request = None
         self.assertEqual([], services_table.get_categories_list())
         mock_catalog_views.get_categories_list.assert_called_once_with(None)
@@ -672,7 +681,8 @@ class TestServicesTable(testtools.TestCase):
 
         mock_get_env_attrs.return_value = (consts.STATUS_ID_READY, None)
         mock_api.Session.get_if_available.return_value = 'session_id'
-        services_table = tables.ServicesTable(None)
+        mock_request = mock.Mock()
+        services_table = tables.ServicesTable(mock_request)
         services_table.kwargs = {'environment_id': 'foo_env_id'}
 
         mock_datum = mock.MagicMock()
@@ -706,7 +716,8 @@ class TestServicesTable(testtools.TestCase):
         mock_reverse.return_value = 'test_url'
 
         mock_get_env_attrs.return_value = (consts.STATUS_ID_DEPLOYING, None)
-        services_table = tables.ServicesTable(None)
+        mock_request = mock.Mock()
+        services_table = tables.ServicesTable(mock_request)
         services_table.kwargs = {'environment_id': 'foo_env_id'}
 
         mock_datum = mock.MagicMock()
@@ -714,21 +725,23 @@ class TestServicesTable(testtools.TestCase):
         self.assertEqual([], actions)
 
     def test_get_repo_url(self):
-        services_table = tables.ServicesTable(None)
+        mock_request = mock.Mock()
+        services_table = tables.ServicesTable(mock_request)
         self.assertEqual(pkg_consts.DISPLAY_MURANO_REPO_URL,
                          services_table.get_repo_url())
 
     @mock.patch.object(tables, 'reverse')
     def test_get_pkg_def_url(self, mock_reverse):
         mock_reverse.return_value = 'test_url'
-        services_table = tables.ServicesTable(None)
+        mock_request = mock.Mock()
+        services_table = tables.ServicesTable(mock_request)
         self.assertEqual('test_url',
                          services_table.get_pkg_def_url())
         mock_reverse.assert_called_once_with(
             'horizon:app-catalog:packages:index')
 
 
-class TestShowDeploymentDetails(testtools.TestCase):
+class TestShowDeploymentDetails(unittest.TestCase):
 
     @mock.patch.object(tables, 'reverse')
     def test_get_link_url(self, mock_reverse):
@@ -750,15 +763,16 @@ class TestShowDeploymentDetails(testtools.TestCase):
         self.assertTrue(show_deployment_details.allowed(None, None))
 
 
-class TestEnvConfigTable(testtools.TestCase):
+class TestEnvConfigTable(unittest.TestCase):
 
     def test_get_object_id(self):
-        env_config_table = tables.EnvConfigTable(None)
+        mock_request = mock.Mock()
+        env_config_table = tables.EnvConfigTable(mock_request)
         self.assertEqual('foo', env_config_table.get_object_id({
             '?': {'id': 'foo'}}))
 
 
-class TestDeploymentHistoryTable(testtools.TestCase):
+class TestDeploymentHistoryTable(unittest.TestCase):
 
     def setUp(self):
         super(TestDeploymentHistoryTable, self).setUp()
