@@ -15,8 +15,8 @@
 from django.core.files import storage
 from django import http
 from django.utils.translation import ugettext_lazy as _
+from unittest import mock
 
-import mock
 
 from horizon import exceptions as horizon_exceptions
 from muranoclient.common import exceptions as exc
@@ -29,9 +29,7 @@ from muranodashboard.packages import views
 from openstack_dashboard.test import helpers
 
 
-class TestPackageView(helpers.APIMockTestCase):
-
-    use_mox = True
+class TestPackageView(helpers.APITestCase):
 
     def setUp(self):
         super(TestPackageView, self).setUp()
@@ -54,8 +52,9 @@ class TestPackageView(helpers.APIMockTestCase):
 
         self.assertIsInstance(response, http.HttpResponse)
         for key, val in expected_response.items():
-            self.assertIn(key.lower(), response._headers)
-            self.assertEqual((key, val), response._headers[key.lower()])
+            key = key.lower()
+            self.assertTrue(response.has_header(key))
+            self.assertEqual(val, response[key])
 
     @mock.patch.object(views, 'exceptions')
     @mock.patch.object(views, 'reverse')
@@ -89,9 +88,7 @@ class TestPackageView(helpers.APIMockTestCase):
         self.assertFalse(views.is_app(mock_wizard))
 
 
-class TestDetailView(helpers.APIMockTestCase):
-
-    use_mox = True
+class TestDetailView(helpers.APITestCase):
 
     def setUp(self):
         super(TestDetailView, self).setUp()
@@ -133,9 +130,7 @@ class TestDetailView(helpers.APIMockTestCase):
             redirect='test_redirect')
 
 
-class TestModifyPackageView(helpers.APIMockTestCase):
-
-    use_mox = True
+class TestModifyPackageView(helpers.RestAPITestCase):
 
     def setUp(self):
         super(TestModifyPackageView, self).setUp()
@@ -194,9 +189,7 @@ class TestModifyPackageView(helpers.APIMockTestCase):
         self.modify_pkg_view.get_form.assert_called_once_with()
 
 
-class TestImportPackageWizard(helpers.APIMockTestCase):
-
-    use_mox = True
+class TestImportPackageWizard(helpers.APITestCase):
 
     def setUp(self):
         super(TestImportPackageWizard, self).setUp()
@@ -790,9 +783,7 @@ class TestImportPackageWizard(helpers.APIMockTestCase):
                           'package': 'test_package'}, kwargs)
 
 
-class TestImportBundleWizard(helpers.APIMockTestCase):
-
-    use_mox = True
+class TestImportBundleWizard(helpers.RestAPITestCase):
 
     def setUp(self):
         super(TestImportBundleWizard, self).setUp()
@@ -1096,7 +1087,7 @@ class TestImportBundleWizard(helpers.APIMockTestCase):
             'horizon:app-catalog:packages:index')
 
 
-class TestPackageDefinitionsView(helpers.APIMockTestCase):
+class TestPackageDefinitionsView(helpers.APITestCase):
 
     def setUp(self):
         super(TestPackageDefinitionsView, self).setUp()
